#!/bin/bash
#

usage()
{
   echo "USAGE: `basename ${0}` <product_directory> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
maketar=${2}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=git
origpkgver=v2_20_1
pkgver=${origpkgver}
pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g'`
ssibuildshims_version=v1_04_13
pkgtarfile=${package}-${pkgdotver}.tar 

get_this_dir
get_ssibuildshims

source define_basics NO_QUAL

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/bin ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} NO_QUAL CURRENT
   exit 0
fi

echo "building ${package} for ${OS}-${plat} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

mkdir -p ${blddir}
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi

cd ${blddir}
tar xf ${product_dir}/${package}/${pkgver}/tar/${pkgtarfile} || ssi_die "failed to unwind ${pkgtarfile}"
cd ${blddir}/git*
patch --verbose -b -p0 < ${patchdir}/git.patch || ssi_die "git patch failed"

# Patch gitk script to swap out references to a color some versions of
# Tcl/Tk don't recognize.
perl -wapi\~ -e 's&\blime\b&"\#32cd32"&g' gitk-git/gitk && rm -f gitk-git/gitk~

# declare now so we can setup
# fake ups declare
fakedb=${product_dir}/${package}/${pkgver}/fakedb
${SSIBUILDSHIMS_DIR}/bin/fake_declare_product ${product_dir} ${package} ${pkgver} NO_QUAL

setup -B ${package} ${pkgver} -z ${fakedb}:${product_dir}:${PRODUCTS}  || ssi_die "fake setup failed"

set -x

# by default, the build creates hard links between files in bin and libexec
# define NO_INSTALL_HARDLINKS to use symbolic links instead
cd ${blddir}/git*
autoconf
./configure --prefix=${pkgdir} 
make -j `${SSIBUILDSHIMS_DIR}/bin/ncores` NO_INSTALL_HARDLINKS=1 ETC_GITATTRIBUTES=config ETC_GITCONFIG=config all install || exit 1
which asciidoc >& /dev/null
if (( $? == 0 )); then
  make -j `${SSIBUILDSHIMS_DIR}/bin/ncores` NO_INSTALL_HARDLINKS=1 ETC_GITATTRIBUTES=config ETC_GITCONFIG=config install-doc || exit 1
else
 echo "INFO: cannot build git documentation"
fi

install -d ${pkgdir}/config || exit 1
install -m 644 ${patchdir}/gitconfig ${pkgdir}/config/ || exit 1
install -d ${pkgdir}/contrib/completion || exit 1
install -m 644 contrib/completion/* ${pkgdir}/contrib/completion  || exit 1

cd ${blddir}/git*/contrib/subtree
make  || exit 1
make install || exit 1
which asciidoc >& /dev/null
if (( $? == 0 )); then
  make install-doc || exit 1
fi

cd ${blddir}/git*

set +x

if [ ! -d ${pkgdir}/bin ]
then
   echo "ERROR: failed to create ${pkgdir}/bin"
   echo "       Something is very wrong"
   exit 1
fi


# real ups declare
${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} NO_QUAL CURRENT

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver} -z ${product_dir}:${PRODUCTS} || ssi_die "setup failed"

# this must be last
if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/bin ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} NO_QUAL CURRENT
fi

exit 0
